#!/bin/csh -f
####################################################################################
#Author: Zhang Tao
#Email: zhangtao@cryst.iphy.ac.cn
#Created time: 2008,05,19
#last Edit: 2008,05,19 
#Group: SM5,  The Institute of Physics, Chinese Academy of Sciences
#####################################################################################

######parameters##################################################
#1: parameters pool
#2: status file
#3: the number of cycles
#4: interface file name
#5: sucess signal
#6: seed
#7: select signal
###################################################################################

source $1
source $2

set interface_file = $html_name/$4

if ( $5 == 1 ) then
  set success_show = "<br>&nbsp;&nbsp;<font color = '#008272'> done&nbsp;&nbsp; "
else
  set success_show = "<br>&nbsp;&nbsp;<font color = '#F20000'> failed&nbsp;&nbsp; "
endif


echo "<table border='0' style='word-break:break-all;word-wrap:break-all' cellpadding='0' cellspacing='0'> " >> $interface_file
echo "<tr>"  >> $interface_file

if ( ${OASIS_MODE} == "DMR"  ) then
  if ( $#argv == 6 ) then
    echo -n "<td width='90'> &nbsp;&nbsp;Cycle $3-$6 </td>"  >> $interface_file
  else
    echo -n "<td width='90'><input type='radio' id='seed' name='seed' value='$6'> Cycle $3-$6 </td>"  >> $interface_file
    set success_show = ""
  endif
else
   echo -n "<td width='70'> &nbsp;&nbsp;Cycle $3 </td>" >>  $interface_file
endif



if ( $OASIS_MODE != "EXT" ) then
  if ( $phase_pro == "oasis" ) then
    if ( ${OASIS_MODE} == "DMR" ) then
      echo -n "<td width='750'>&nbsp;&nbsp; Phasing: <a href='../$phase_log'  target = top>OASIS-SigmaA</a>;&nbsp;" >> $interface_file
    else
      echo -n "<td width='750'>&nbsp;&nbsp; Phasing: <a href='../$phase_log'  target = top>OASIS</a>;&nbsp;" >> $interface_file
    endif
  else 
    echo -n "<td>Phasing: <a href='../$phase_log'  target = top>PHASER</a>;&nbsp;" >> $interface_file
  endif
  if ( $phase_status == 0 ) then
    echo "<font color = '#F20000'><br>&nbsp;&nbsp;error in phasing</td>" >> $interface_file
    goto error1
  endif

  if ( $if_dm == 1 ) then
    if ( $dm_pro == "dm" ) then
      echo -n "Density modification: <a href='../$dm_log'  target = top>DM</a>;&nbsp;" >> $interface_file
    else if ( $dm_pro == "resolve" ) then
      echo -n "Density modification: <a href='../$dm_log'  target = top>RESOLVE</a>;&nbsp;" >> $interface_file
    endif
    if ( $dm_status == 0 ) then
      echo "<font color = '#F20000'><br>&nbsp;&nbsp;error in density modification</td>" >> $interface_file
      goto error1
    endif
  endif
else
  echo "<td width='750'>" >> $interface_file
endif


if ( $build_pro == "resolve" ) then
    echo -n "&nbsp;Model building: <a href='../$build_log'  target = top>RESOLVE</a>;&nbsp;&nbsp;" >> $interface_file
  if ( $build_status == 0 ) then
    echo "<font color = '#F20000'><br>&nbsp;&nbsp; error in model building" >> $interface_file
    goto error0
  endif
else if ( $build_pro == "arp" ) then
      echo -n "&nbsp; Model building: <a href='../$build_log' target = top>ARP/wARP-REFMAC5</a>;&nbsp;&nbsp;" >> $interface_file
  if ( $build_status == 0 ) then
    echo "<br><font color = '#F20000'>&nbsp;&nbsp; error in model building" >> $interface_file
    goto error0
  endif
else if ( $build_pro == "phenix" ) then
    echo -n "&nbsp;Model building: <a href='../$build_log'  target = top>PHENIX.AutoBuild</a>;&nbsp;&nbsp;" >> $interface_file
  if ( $build_status == 0 ) then
    echo "<font color = '#F20000'><br>&nbsp;&nbsp; error in model building" >> $interface_file
    goto error0
  endif
endif 


error0:

echo "</td>" >> $interface_file

set s_model = '&nbsp;&nbsp;<a href="javascript:view_pdb('
set pymol_path = `which phenix.pymol`

if ( $?build_pdb_out == 1 ) then
  set s_model =  "${s_model}'${build_pdb_out}'"
endif
set s_model = "${s_model},'$pymol_path')"'"'">show model</a></font>"


###RESOLVE############################################################
if ( $build_status == 1 ) then
  if ( $build_pro == "resolve" ) then
    echo "<tr><td>&nbsp;</td> <td><font size = '3' > &nbsp;&nbsp;<font color = '#0000FF'>${recommend[2]}</font> residues buildt with <font color = '#0000FF'>${recommend[1]}</font> placed<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;build score (residues built + placed - 2* # of chains not assigned to sequence)= <font color = '#0000FF'>${recommend[3]}</font>${s_model}</font> " >> $interface_file

###ARP/wARP###########################################################
  else if ( $build_pro == "arp" ) then
    if ( $rfree_signal == 1 ) then
      if ( $arp_select_mode == "normal" ) then
        echo "<tr><td>&nbsp;</td> <td><font size = '3' > &nbsp;&nbsp; <font color = '#0000FF'>${recommend[2]}</font> residues buildt with <font color = '#0000FF'>${recommend[1]}</font> docked into the sequence; R factor = <font color = '#0000FF'>${recommend[3]}</font>;&nbsp;Rfree factor = <font color = '#0000FF'>${recommend[4]}</font>${s_model}</font><br>" >> $interface_file
        echo "<font size = '3' >&nbsp;&nbsp; Solution selected according to ARP/wARP's default." >> $interface_file
      else if ( $arp_select_mode == "dbest" ) then
        echo "<tr><td>&nbsp;</td> <td><font size = '3' > &nbsp;&nbsp; <font color = '#0000FF'>${dock_best[2]}</font> residues buildt with <font color = '#0000FF'>${dock_best[1]}</font> docked into the sequence; R factor = <font color = '#0000FF'>${dock_best[3]}</font>;&nbsp;Rfree factor = <font color = '#0000FF'>${dock_best[5]}</font>${s_model}</font><br> " >> $interface_file
        echo "<font size = '3' >&nbsp;&nbsp; Solution selected according to residues docked in sequence." >> $interface_file
      else if ( $arp_select_mode == "cbest" ) then
        echo "<tr><td>&nbsp;</td> <td><font size = '3' > &nbsp;&nbsp; <font color = '#0000FF'>${res_best[2]}</font> residues buildt with <font color = '#0000FF'>${res_best[1]}</font> docked into the sequence; R factor = <font color = '#0000FF'>${res_best[3]}</font>;&nbsp;Rfree factor = <font color = '#0000FF'>${res_best[5]}</font>${s_model}</font><br>  " >> $interface_file
        echo "<font size = '3' >&nbsp;&nbsp; Solution selected according to residues in all." >> $interface_file
      else if ( $arp_select_mode == "rbest" ) then
        echo "<tr><td>&nbsp;</td> <td><font size = '3' > &nbsp;&nbsp; <font color = '#0000FF'>${r_best[2]}</font> residues buildt with <font color = '#0000FF'>${r_best[1]}</font> docked into the sequence; R factor = <font color = '#0000FF'>${r_best[3]}</font>;&nbsp;Rfree factor = <font color = '#0000FF'>${r_best[5]}</font>${s_model}</font><br>  " >> $interface_file
        echo "<font size = '3' >&nbsp;&nbsp; Solution selected according to R factor." >> $interface_file
      else if ( $arp_select_mode == "rfree" ) then
        echo "<tr><td>&nbsp;</td> <td><font size = '3' >&nbsp;&nbsp; <font color = '#0000FF'>${rfree_best[2]}</font> residues buildt with <font color = '#0000FF'>${rfree_best[1]}</font> docked into the sequence; R factor = <font color = '#0000FF'>${rfree_best[3]}</font>;&nbsp;Rfree factor = <font color = '#0000FF'>${rfree_best[5]}</font>${s_model}</font><br>  " >> $interface_file
      echo "<font size = '3' >&nbsp;&nbsp; Solution selected according Rfree factor." >> $interface_file
  endif
else
    if ( $arp_select_mode == "normal" ) then
      echo "<tr><td>&nbsp;</td> <td><font size = '3' > &nbsp;&nbsp; <font color = '#0000FF'>${recommend[2]}</font> residues buildt with <font color = '#0000FF'>${recommend[1]}</font> docked into the sequence; R factor = <font color = '#0000FF'>${recommend[3]}</font>${s_model}</font><br> " >> $interface_file
      echo "<font size = '3' >&nbsp;&nbsp; Solution selected according to ARP/wARP's default." >> $interface_file
    else if ( $arp_select_mode == "dbest" ) then
        echo "<tr><td>&nbsp;</td> <td><font size = '3' >&nbsp;&nbsp; <font color = '#0000FF'>${dock_best[2]}</font> residues buildt with <font color = '#0000FF'>${dock_best[1]}</font> docked into the sequence; R factor = <font color = '#0000FF'>${dock_best[3]}</font>${s_model}</font><br> " >> $interface_file
        echo "<font size = '3' >&nbsp;&nbsp; Solution selected according to residues docked in sequence." >> $interface_file
    else if ( $arp_select_mode == "cbest" ) then
        echo "<tr><td>&nbsp;</td> <td><font size = '3' > &nbsp;&nbsp; <font color = '#0000FF'>${res_best[2]}</font> residues buildt with <font color = '#0000FF'>${res_best[1]}</font> docked into the sequence; R factor = <font color = '#0000FF'>${res_best[3]}</font>${s_model}</font><br> " >> $interface_file
        echo "<font size = '3' >&nbsp;&nbsp; Solution selected according to residues in all." >> $interface_file
    else if ( $arp_select_mode == "rbest" ) then
        echo "<tr><td>&nbsp;</td> <td><font size = '3' >&nbsp;&nbsp; <font color = '#0000FF'>${r_best[2]}</font> residues buildt with <font color = '#0000FF'>${r_best[1]}</font> docked into the sequence; R factor = <font color = '#0000FF'>${r_best[3]}</font>${s_model}</font><br> " >> $interface_file
        echo "<font size = '3' >&nbsp;&nbsp; Solution selected according to R factor." >> $interface_file
    endif
  endif
###phenix##############################################################
  else if ( $build_pro == "phenix" ) then
    echo "<tr><td>&nbsp;</td> <td><font size = '3' >&nbsp;&nbsp; <font color = '#0000FF'>${recommend[2]}</font> residues buildt with <font color = '#0000FF'>${recommend[1]}</font> placed; map-model CC =  <font color = '#0000FF'>${recommend[3]}</font>; R factor = <font color = '#0000FF'>${recommend[4]}</font>; Rfree factor = <font color = '#0000FF'>${recommend[5]}</font>${s_model}</font>" >> $interface_file
  endif

else
  echo "<tr><td>&nbsp;</td> <td><font size = '3' >  " >> $interface_file
endif




error1:
echo "$success_show</td></tr></table>"  >> $interface_file
echo "<div  id = 'inter_$id' name='inter_$id'  style='display:none;' >" >> $interface_file
echo "<table width='90%' border='0' align='center' cellpadding='0' style='word-break:break-all;word-wrap:break-all' cellspacing='0'> " >> $interface_file
if ( ${OASIS_MODE} != "DMR" ) then
  if ( ${OASIS_MODE} == "EXT" ) then
    echo -n "<tr><td   colspan =2  ><font size = '6' > Extending model"  >> $interface_file
    echo ": </font></td></tr>" >> $interface_file
  else
    echo -n "<tr><td   colspan =2  ><font size = '6' > Cycle $3"  >> $interface_file
    echo ": </font></td></tr>" >> $interface_file
  endif
else
  echo -n "<tr><td   colspan = 2 ><font size = '6'> Cycle $3 and trial $6" >> $interface_file
  echo ": </font></td></tr>" >> $interface_file
endif


echo "<tr height=90 >" >> $interface_file
echo "<td width=90  >" >> $interface_file
echo "<center>" >> $interface_file
echo -n '<font size = "3" > <a href="javascript:view_pdb(' >> $interface_file
set pymol_path = `which phenix.pymol`
if ( $?build_pdb_out == 1 ) then
  echo -n "'$build_pdb_out'" >> $interface_file
endif
echo ",'$pymol_path'"'"'")> <img border='0' height=75 width=75  src='./PyMOL.gif' ><br><font size = '2' >Show model</font> </a> </font>" >> $interface_file
echo "</center>" >> $interface_file
echo "</td>" >> $interface_file
echo "<td>" >> $interface_file


if ( ${OASIS_MODE} == "EXT" ) goto build
if ( $phase_status == 1 ) then
  if ( $phase_pro == "oasis" ) then
    echo "<font size = '3' > OASIS: average FOM = $average_fom.&nbsp;<a href='../$phase_log'  target = top>details</a> </font><br>" >> $interface_file
  else 
    echo "<font size = '3' > PHASER:&nbsp;<a href='../$phase_log'  target = top>details</a> </font><br>" >> $interface_file
  endif
else
  if ( $phase_pro == "oasis" ) then
    echo "<font size = '3' > OASIS: ERROR &nbsp;<a href='../$phase_log'  target = top>details</a> </font><br>" >> $interface_file
  else 
    echo "<font size = '3' > PHASER: ERROR &nbsp;<a href='../$phase_log'  target = top>details</a> </font><br>" >> $interface_file
  endif
  goto error2
endif


if ( $if_dm == "1" ) then
  if ( $dm_status == 1 ) then
    if ( $dm_pro == "dm" ) then
      echo "<font size = '3' > DM:&nbsp; <a href='../$dm_log'  target = top>details</a></font><br>" >> $interface_file
    else if ( $dm_pro == "resolve" ) then
      echo "<font size = '3' > RESOLVE:&nbsp; <a href='../$dm_log'  target = top>details</a></font><br>" >> $interface_file
    endif
  else
    if ( $dm_pro == "dm" ) then
      echo "<font size = '3' > DM: ERROR &nbsp; <a href='../$dm_log'  target = top>details</a></font><br>" >> $interface_file
    else if ( $dm_pro == "resolve" ) then
      echo "<font size = '3' > RESOLVE: ERROR &nbsp; <a href='../$dm_log'  target = top>details</a></font><br>" >> $interface_file
    endif
    goto error2
    endif
endif

build:

###RESOLVE############################################################
if ( $build_status == 1 ) then
  if ( $build_pro == "resolve" ) then
    echo "<font size = '3' > RESOLVE: ${recommend[2]} residues buildt with ${recommend[1]} placed<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;build score (residues built + placed - 2* # of chains not assigned to sequence)= ${recommend[3]} " >> $interface_file

###ARP/wARP###########################################################
  else if ( $build_pro == "arp" ) then
    if ( $rfree_signal == 1 ) then
      if ( $arp_select_mode == "normal" ) then
        echo "<font size = '3' >ARP/wARP: ${recommend[2]} residues buildt with ${recommend[1]} docked into the sequence; R factor = ${recommend[3]};&nbsp;Rfree factor = ${recommend[4]} </font><br>" >> $interface_file
        echo "<font size = '3' >Output model: selected according to ARP/wARP's recommend." >> $interface_file
      else if ( $arp_select_mode == "dbest" ) then
        echo "<font size = '3' >ARP/wARP: ${dock_best[2]} residues buildt with ${dock_best[1]} docked into the sequence; R factor = ${dock_best[3]};&nbsp;Rfree factor = ${dock_best[5]} </font><br> " >> $interface_file
        echo "<font size = '3' >Output model: selected according to residues docked in sequence." >> $interface_file
      else if ( $arp_select_mode == "cbest" ) then
        echo "<font size = '3' >ARP/wARP: ${res_best[2]} residues buildt with ${res_best[1]} docked into the sequence; R factor = ${res_best[3]};&nbsp;Rfree factor = ${res_best[5]}</font><br>  " >> $interface_file
        echo "<font size = '3' >Output model: selected according to residues in all." >> $interface_file
      else if ( $arp_select_mode == "rbest" ) then
        echo "<font size = '3' >ARP/wARP: ${r_best[2]} residues buildt with ${r_best[1]} docked into the sequence; R factor = ${r_best[3]};&nbsp;Rfree factor = ${r_best[5]}</font><br>  " >> $interface_file
        echo "<font size = '3' >Output model: selected according to R factor." >> $interface_file
      else if ( $arp_select_mode == "rfree" ) then
        echo "<font size = '3' >ARP/wARP: ${rfree_best[2]} residues buildt with ${rfree_best[1]} docked into the sequence; R factor = ${rfree_best[3]};&nbsp;Rfree factor = ${rfree_best[5]}</font><br>  " >> $interface_file
      echo "<font size = '3' >Output model: selected according Rfree factor." >> $interface_file
  endif
else
    if ( $arp_select_mode == "normal" ) then
      echo "<font size = '3' >ARP/wARP: ${recommend[2]} residues buildt with ${recommend[1]} docked into the sequence; R factor = ${recommend[3]}</font><br> " >> $interface_file
      echo "<font size = '3' >Output model: selected according to ARP/wARP's recommend." >> $interface_file
    else if ( $arp_select_mode == "dbest" ) then
        echo "<font size = '3' >ARP/wARP: ${dock_best[2]} residues buildt with ${dock_best[1]} docked into the sequence; R factor = ${dock_best[3]}</font><br> " >> $interface_file
        echo "<font size = '3' >Output model: selected according to residues docked in sequence." >> $interface_file
    else if ( $arp_select_mode == "cbest" ) then
        echo "<font size = '3' >ARP/wARP: ${res_best[2]} residues buildt with ${res_best[1]} docked into the sequence; R factor = ${res_best[3]}</font><br> " >> $interface_file
        echo "<font size = '3' >Output model: selected according to residues in all." >> $interface_file
    else if ( $arp_select_mode == "rbest" ) then
        echo "<font size = '3' >ARP/wARP: ${r_best[2]} residues buildt with ${r_best[1]} docked into the sequence; R factor = ${r_best[3]}</font><br> " >> $interface_file
        echo "<font size = '3' >Output model: selected according to R factor." >> $interface_file
    endif
  endif
###phenix##############################################################
  else if ( $build_pro == "phenix" ) then
    echo "<font size = '3' > PHENIX.AutoBuild: ${recommend[2]} residues buildt with ${recommend[1]} placed; map-model CC =  ${recommend[3]}; R factor = ${recommend[4]}; Rfree factor = ${recommend[5]}" >> $interface_file
  endif
else
  if ( $build_pro == "resolve" ) then
    echo "<font size = '3' > RESOLVE: building error " >> $interface_file
  else if ( $build_pro == "arp" ) then
    echo "<font size = '3' > ARP/wARP: building error " >> $interface_file
  else if ( $build_pro == "phenix" ) then
    echo "<font size = '3' > PHENIX.AutoBuild: building error " >> $interface_file
  endif
endif
echo "<a href='../$build_log'  target = top>details</a> </font><br>" >> $interface_file
error2:
echo "</td></tr>" >> $interface_file
#${oasisbin}/html/picture.csh $build_pdb_out $html_name/$id
#echo "<td><img src='$id.png'  height=200> </td></tr>" >> $interface_file
#echo "<tr><td>&nbsp;&nbsp;&nbsp;</td></tr>" >> $interface_file
echo "</table>" >> $interface_file
echo "</div>"  >> $interface_file
#echo "i[$id]=$interface_file" >> $html_name/.inter.par

